tiled.adapters.files.DirectoryAdapter
=====================================

.. currentmodule:: tiled.adapters.files

.. autoclass:: DirectoryAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DirectoryAdapter.__init__
      ~DirectoryAdapter.authenticated_as
      ~DirectoryAdapter.from_directory
      ~DirectoryAdapter.get
      ~DirectoryAdapter.items
      ~DirectoryAdapter.keys
      ~DirectoryAdapter.new_variation
      ~DirectoryAdapter.read
      ~DirectoryAdapter.register_query
      ~DirectoryAdapter.register_query_lazy
      ~DirectoryAdapter.search
      ~DirectoryAdapter.shutdown_watcher
      ~DirectoryAdapter.sort
      ~DirectoryAdapter.update_now
      ~DirectoryAdapter.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DirectoryAdapter.DEFAULT_MIMETYPES_BY_FILE_EXT
      ~DirectoryAdapter.DEFAULT_READERS_BY_MIMETYPE
      ~DirectoryAdapter.access_policy
      ~DirectoryAdapter.background_tasks
      ~DirectoryAdapter.directory
      ~DirectoryAdapter.entries_stale_after
      ~DirectoryAdapter.entries_stale_at
      ~DirectoryAdapter.include_routers
      ~DirectoryAdapter.items_indexer
      ~DirectoryAdapter.keys_indexer
      ~DirectoryAdapter.metadata
      ~DirectoryAdapter.metadata_stale_after
      ~DirectoryAdapter.metadata_stale_at
      ~DirectoryAdapter.must_revalidate
      ~DirectoryAdapter.principal
      ~DirectoryAdapter.query_registry
      ~DirectoryAdapter.structure_family
      ~DirectoryAdapter.values_indexer
   
   